@@ -233,12 +233,10 @@ class TD:
             hist_data = self.historical_websocket.get_hist_tick_data(contract, )
         else:
             bar_size = bar_size.replace(' ', '')
+            if bar_size[-1] == 's':
+                bar_size = bar_size[:-1]
             query_time = query_time.strftime('%Y-%m-%d') + 'T23:59:59'
             start_time = start_time.strftime('%Y-%m-%d') + 'T00:00:00'
-            print(contract)
-            print(query_time)
-            print(start_time)
-            print(bar_size)
             hist_data = self.historical_websocket.get_hist_bar_data(contract, query_time, start_time, bar_size)
         DEFAULT_HISTORIC_DATA_ID = DEFAULT_HISTORIC_DATA_ID + 1
         self.hist_data[ticker_id] = hist_data
