@@ -14,6 +14,9 @@ class LiveData:
         self.oi = None
         self.turnover = None
         self.special_tag = ""
+        self.day_high = None
+        self.day_low = None
+        self.day_open = None
         # self.bids = []
         # self.asks = []
 
@@ -44,9 +47,14 @@ class TouchlineData:
     def __init__(self):
         self.symbol = None
         self.truedata_id = None
-        self.raw_data = None
         self.open = None
         self.high = None
         self.low = None
         self.close = None
         self.prev_close = None
+        self.ttq = None
+        self.oi = None
+        self.turnover = None
+
+    def __str__(self):
+        return str(self.__dict__)
